// Code generated by "stringer -type=actionType"; DO NOT EDIT.

package fzf

import "strconv"

func _() {
	// An "invalid array index" compiler error signifies that the constant values have changed.
	// Re-run the stringer command to generate them again.
	var x [1]struct{}
	_ = x[actIgnore-0]
	_ = x[actStart-1]
	_ = x[actClick-2]
	_ = x[actInvalid-3]
	_ = x[actBracketedPasteBegin-4]
	_ = x[actBracketedPasteEnd-5]
	_ = x[actChar-6]
	_ = x[actMouse-7]
	_ = x[actBeginningOfLine-8]
	_ = x[actAbort-9]
	_ = x[actAccept-10]
	_ = x[actAcceptNonEmpty-11]
	_ = x[actAcceptOrPrintQuery-12]
	_ = x[actBackwardChar-13]
	_ = x[actBackwardDeleteChar-14]
	_ = x[actBackwardDeleteCharEof-15]
	_ = x[actBackwardWord-16]
	_ = x[actCancel-17]
	_ = x[actChangeBorderLabel-18]
	_ = x[actChangeGhost-19]
	_ = x[actChangeHeader-20]
	_ = x[actChangeFooter-21]
	_ = x[actChangeHeaderLabel-22]
	_ = x[actChangeFooterLabel-23]
	_ = x[actChangeInputLabel-24]
	_ = x[actChangeListLabel-25]
	_ = x[actChangeMulti-26]
	_ = x[actChangeNth-27]
	_ = x[actChangePointer-28]
	_ = x[actChangePreview-29]
	_ = x[actChangePreviewLabel-30]
	_ = x[actChangePreviewWindow-31]
	_ = x[actChangePrompt-32]
	_ = x[actChangeQuery-33]
	_ = x[actClearScreen-34]
	_ = x[actClearQuery-35]
	_ = x[actClearSelection-36]
	_ = x[actClose-37]
	_ = x[actDeleteChar-38]
	_ = x[actDeleteCharEof-39]
	_ = x[actEndOfLine-40]
	_ = x[actFatal-41]
	_ = x[actForwardChar-42]
	_ = x[actForwardWord-43]
	_ = x[actKillLine-44]
	_ = x[actKillWord-45]
	_ = x[actUnixLineDiscard-46]
	_ = x[actUnixWordRubout-47]
	_ = x[actYank-48]
	_ = x[actBackwardKillWord-49]
	_ = x[actSelectAll-50]
	_ = x[actDeselectAll-51]
	_ = x[actToggle-52]
	_ = x[actToggleSearch-53]
	_ = x[actToggleAll-54]
	_ = x[actToggleDown-55]
	_ = x[actToggleUp-56]
	_ = x[actToggleIn-57]
	_ = x[actToggleOut-58]
	_ = x[actToggleTrack-59]
	_ = x[actToggleTrackCurrent-60]
	_ = x[actToggleHeader-61]
	_ = x[actToggleWrap-62]
	_ = x[actToggleMultiLine-63]
	_ = x[actToggleHscroll-64]
	_ = x[actTrackCurrent-65]
	_ = x[actToggleInput-66]
	_ = x[actHideInput-67]
	_ = x[actShowInput-68]
	_ = x[actUntrackCurrent-69]
	_ = x[actDown-70]
	_ = x[actUp-71]
	_ = x[actPageUp-72]
	_ = x[actPageDown-73]
	_ = x[actPosition-74]
	_ = x[actHalfPageUp-75]
	_ = x[actHalfPageDown-76]
	_ = x[actOffsetUp-77]
	_ = x[actOffsetDown-78]
	_ = x[actOffsetMiddle-79]
	_ = x[actJump-80]
	_ = x[actJumpAccept-81]
	_ = x[actPrintQuery-82]
	_ = x[actRefreshPreview-83]
	_ = x[actReplaceQuery-84]
	_ = x[actToggleSort-85]
	_ = x[actShowPreview-86]
	_ = x[actHidePreview-87]
	_ = x[actTogglePreview-88]
	_ = x[actTogglePreviewWrap-89]
	_ = x[actTransform-90]
	_ = x[actTransformBorderLabel-91]
	_ = x[actTransformGhost-92]
	_ = x[actTransformHeader-93]
	_ = x[actTransformFooter-94]
	_ = x[actTransformHeaderLabel-95]
	_ = x[actTransformFooterLabel-96]
	_ = x[actTransformInputLabel-97]
	_ = x[actTransformListLabel-98]
	_ = x[actTransformNth-99]
	_ = x[actTransformPointer-100]
	_ = x[actTransformPreviewLabel-101]
	_ = x[actTransformPrompt-102]
	_ = x[actTransformQuery-103]
	_ = x[actTransformSearch-104]
	_ = x[actBgTransform-105]
	_ = x[actBgTransformBorderLabel-106]
	_ = x[actBgTransformGhost-107]
	_ = x[actBgTransformHeader-108]
	_ = x[actBgTransformFooter-109]
	_ = x[actBgTransformHeaderLabel-110]
	_ = x[actBgTransformFooterLabel-111]
	_ = x[actBgTransformInputLabel-112]
	_ = x[actBgTransformListLabel-113]
	_ = x[actBgTransformNth-114]
	_ = x[actBgTransformPointer-115]
	_ = x[actBgTransformPreviewLabel-116]
	_ = x[actBgTransformPrompt-117]
	_ = x[actBgTransformQuery-118]
	_ = x[actBgTransformSearch-119]
	_ = x[actBgCancel-120]
	_ = x[actSearch-121]
	_ = x[actPreview-122]
	_ = x[actPreviewTop-123]
	_ = x[actPreviewBottom-124]
	_ = x[actPreviewUp-125]
	_ = x[actPreviewDown-126]
	_ = x[actPreviewPageUp-127]
	_ = x[actPreviewPageDown-128]
	_ = x[actPreviewHalfPageUp-129]
	_ = x[actPreviewHalfPageDown-130]
	_ = x[actPrevHistory-131]
	_ = x[actPrevSelected-132]
	_ = x[actPrint-133]
	_ = x[actPut-134]
	_ = x[actNextHistory-135]
	_ = x[actNextSelected-136]
	_ = x[actExecute-137]
	_ = x[actExecuteSilent-138]
	_ = x[actExecuteMulti-139]
	_ = x[actSigStop-140]
	_ = x[actFirst-141]
	_ = x[actLast-142]
	_ = x[actReload-143]
	_ = x[actReloadSync-144]
	_ = x[actDisableSearch-145]
	_ = x[actEnableSearch-146]
	_ = x[actSelect-147]
	_ = x[actDeselect-148]
	_ = x[actUnbind-149]
	_ = x[actRebind-150]
	_ = x[actToggleBind-151]
	_ = x[actBecome-152]
	_ = x[actShowHeader-153]
	_ = x[actHideHeader-154]
	_ = x[actBell-155]
	_ = x[actExclude-156]
	_ = x[actExcludeMulti-157]
	_ = x[actAsync-158]
}

const _actionType_name = "actIgnoreactStartactClickactInvalidactBracketedPasteBeginactBracketedPasteEndactCharactMouseactBeginningOfLineactAbortactAcceptactAcceptNonEmptyactAcceptOrPrintQueryactBackwardCharactBackwardDeleteCharactBackwardDeleteCharEofactBackwardWordactCancelactChangeBorderLabelactChangeGhostactChangeHeaderactChangeFooteractChangeHeaderLabelactChangeFooterLabelactChangeInputLabelactChangeListLabelactChangeMultiactChangeNthactChangePointeractChangePreviewactChangePreviewLabelactChangePreviewWindowactChangePromptactChangeQueryactClearScreenactClearQueryactClearSelectionactCloseactDeleteCharactDeleteCharEofactEndOfLineactFatalactForwardCharactForwardWordactKillLineactKillWordactUnixLineDiscardactUnixWordRuboutactYankactBackwardKillWordactSelectAllactDeselectAllactToggleactToggleSearchactToggleAllactToggleDownactToggleUpactToggleInactToggleOutactToggleTrackactToggleTrackCurrentactToggleHeaderactToggleWrapactToggleMultiLineactToggleHscrollactTrackCurrentactToggleInputactHideInputactShowInputactUntrackCurrentactDownactUpactPageUpactPageDownactPositionactHalfPageUpactHalfPageDownactOffsetUpactOffsetDownactOffsetMiddleactJumpactJumpAcceptactPrintQueryactRefreshPreviewactReplaceQueryactToggleSortactShowPreviewactHidePreviewactTogglePreviewactTogglePreviewWrapactTransformactTransformBorderLabelactTransformGhostactTransformHeaderactTransformFooteractTransformHeaderLabelactTransformFooterLabelactTransformInputLabelactTransformListLabelactTransformNthactTransformPointeractTransformPreviewLabelactTransformPromptactTransformQueryactTransformSearchactBgTransformactBgTransformBorderLabelactBgTransformGhostactBgTransformHeaderactBgTransformFooteractBgTransformHeaderLabelactBgTransformFooterLabelactBgTransformInputLabelactBgTransformListLabelactBgTransformNthactBgTransformPointeractBgTransformPreviewLabelactBgTransformPromptactBgTransformQueryactBgTransformSearchactBgCancelactSearchactPreviewactPreviewTopactPreviewBottomactPreviewUpactPreviewDownactPreviewPageUpactPreviewPageDownactPreviewHalfPageUpactPreviewHalfPageDownactPrevHistoryactPrevSelectedactPrintactPutactNextHistoryactNextSelectedactExecuteactExecuteSilentactExecuteMultiactSigStopactFirstactLastactReloadactReloadSyncactDisableSearchactEnableSearchactSelectactDeselectactUnbindactRebindactToggleBindactBecomeactShowHeaderactHideHeaderactBellactExcludeactExcludeMultiactAsync"

var _actionType_index = [...]uint16{0, 9, 17, 25, 35, 57, 77, 84, 92, 110, 118, 127, 144, 165, 180, 201, 225, 240, 249, 269, 283, 298, 313, 333, 353, 372, 390, 404, 416, 432, 448, 469, 491, 506, 520, 534, 547, 564, 572, 585, 601, 613, 621, 635, 649, 660, 671, 689, 706, 713, 732, 744, 758, 767, 782, 794, 807, 818, 829, 841, 855, 876, 891, 904, 922, 938, 953, 967, 979, 991, 1008, 1015, 1020, 1029, 1040, 1051, 1064, 1079, 1090, 1103, 1118, 1125, 1138, 1151, 1168, 1183, 1196, 1210, 1224, 1240, 1260, 1272, 1295, 1312, 1330, 1348, 1371, 1394, 1416, 1437, 1452, 1471, 1495, 1513, 1530, 1548, 1562, 1587, 1606, 1626, 1646, 1671, 1696, 1720, 1743, 1760, 1781, 1807, 1827, 1846, 1866, 1877, 1886, 1896, 1909, 1925, 1937, 1951, 1967, 1985, 2005, 2027, 2041, 2056, 2064, 2070, 2084, 2099, 2109, 2125, 2140, 2150, 2158, 2165, 2174, 2187, 2203, 2218, 2227, 2238, 2247, 2256, 2269, 2278, 2291, 2304, 2311, 2321, 2336, 2344}

func (i actionType) String() string {
	if i < 0 || i >= actionType(len(_actionType_index)-1) {
		return "actionType(" + strconv.FormatInt(int64(i), 10) + ")"
	}
	return _actionType_name[_actionType_index[i]:_actionType_index[i+1]]
}
